\name{dendrolines}
\alias{dendrolines}
\alias{plot.nclust}
\title{Fast drawing of dendrograms}
\description{Draw dendrograms by constructing a set of points
of a polygon}
\usage{
dendrolines( clust, hang=0.1, branchtype = "s" )

plot.nclust( clust, hang = 0.1, branchtype = "s" ) 
}

\arguments{
\item{clust}{Cluster object resulting from \code{hclust} or \code{nclust}}
\item{hang}{Length of terminal edge, as a portion of total tree height}
\item{branchtype}{If equals \code{"s"}, the branch are
`shouldered', just like the ouput
of \code{plclust}. Otherwise, they are straight lines. }
\item{height}{If supplied, use this instead of the one in the \code{clust} object}
}

\details{
Drawing a dendrogram can be done by drawing a set of ``forks'' (where
internal nodes bifurcates). However, this can be too slow for large
dendrograms due to many separate calls to line-drawing graphic routines.
Instead of a set of forks, \code{dendrolines} draws a dendrogram as a
single contiguous polygon that tracks the depth-first traversal of
the tree, including backtracking to parents. The number of points
are roughly doubled since internal nodes and ``shoulders'' need to
be visited twice. However, only a single call to line-segment drawing
routine is needed.
}
\value{
\code{dendrolines} returns a list with two elements, \code{x}
and \code{y}, that can be treated as coordinates, for example
can be used directly as input to \code{lines} or \code{plot.default}.

}
\author{Pratyaksha Wirapati}

\seealso{nclust,plclust}

\examples{
  h <- hclust(dist(USArrests),"ave")
  p <- dendrolines(h)
  plot(p, type="l")
  plot(p$x, -p$y, type="l") # grow upward (like real tree)
  plot(p$y, p$x, type="l") # turn it on the side
  
  # make shoulderless branch
  p <- dendrolines(hclust(dist(USArrests),"ave"),branchtype="e") 
  plot(p, type="l")

  # we can make the tree grow radially
  plot( t( apply(rbind(p$x,p$y), 2, function(v) 
    c(cos(v[1]/50*3.14),sin(v[1]/50*3.14))*(max(p$y)-v[2]))), type="l",
    xlab="",ylab="")

  # a convenient packaging; and show straight instead of shouldered edge
  plot.nclust( h, branchtype="e")
}
